{% macro upload_button(request, id, text='Browse', class='', data_name='') %}
<div id="{{ id }}-group">
<span id="{{ id }}" class="btn btn-default btn-file {{ class }}" data-name="{{ data_name }}" disabled>{{ text }} <input type="file" data-url="{{ request.route_path('files.json') }}" disabled></span>
<span class="feedback"></span>
</div>
{% endmacro %}
